@@ -16,6 +16,8 @@
 #define ACS_HLINE    SLSMG_HLINE_CHAR
 #define ACS_LTEE     SLSMG_LTEE_CHAR
 #define ACS_RTEE     SLSMG_RTEE_CHAR
+#define ACS_TTEE     SLSMG_UTEE_CHAR
+#define ACS_BTEE     SLSMG_DTEE_CHAR
 #define ACS_ULCORNER SLSMG_ULCORN_CHAR
 #define ACS_LLCORNER SLSMG_LLCORN_CHAR
 #define ACS_URCORNER SLSMG_URCORN_CHAR
