@@ -1,9 +1,8 @@
 /*
    Routines for parsing output from the 'ls' command.
 
-   Copyright (C) 1988, 1992, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-   2005, 2006, 2007, 2011
-   The Free Software Foundation, Inc.
+   Copyright (C) 1988-2014
+   Free Software Foundation, Inc.
 
    Copyright (C) 1995, 1996 Miguel de Icaza
 
