@@ -1,8 +1,8 @@
 /*
    Util for external clipboard.
 
-   Copyright (C) 2009, 2011
-   The Free Software Foundation, Inc.
+   Copyright (C) 2009-2014
+   Free Software Foundation, Inc.
 
    Written by:
    Ilia Maslakov <il.smind@gmail.com>, 2010.
@@ -36,7 +36,6 @@
 
 #include "lib/vfs/vfs.h"
 
-#include "main.h"
 #include "src/execute.h"
 
 #include "clipboard.h"
@@ -66,7 +65,6 @@ clipboard_file_to_ext_clip (const gchar * event_group_name, const gchar * event_
                             gpointer init_data, gpointer data)
 {
     char *tmp, *cmd;
-    int res = 0;
     const char *d = getenv ("DISPLAY");
 
     (void) event_group_name;
@@ -81,7 +79,7 @@ clipboard_file_to_ext_clip (const gchar * event_group_name, const gchar * event_
     cmd = g_strconcat (clipboard_store_path, " ", tmp, " 2>/dev/null", (char *) NULL);
 
     if (cmd != NULL)
-        res = my_system (EXECUTE_AS_SHELL, shell, cmd);
+        my_system (EXECUTE_AS_SHELL, mc_global.tty.shell, cmd);
 
     g_free (cmd);
     g_free (tmp);
@@ -96,7 +94,6 @@ clipboard_file_from_ext_clip (const gchar * event_group_name, const gchar * even
                               gpointer init_data, gpointer data)
 {
     char *tmp, *cmd;
-    int res = 0;
     const char *d = getenv ("DISPLAY");
 
     (void) event_group_name;
@@ -111,7 +108,7 @@ clipboard_file_from_ext_clip (const gchar * event_group_name, const gchar * even
     cmd = g_strconcat (clipboard_paste_path, " > ", tmp, " 2>/dev/null", (char *) NULL);
 
     if (cmd != NULL)
-        res = my_system (EXECUTE_AS_SHELL, shell, cmd);
+        my_system (EXECUTE_AS_SHELL, mc_global.tty.shell, cmd);
 
     g_free (cmd);
     g_free (tmp);
@@ -127,7 +124,6 @@ clipboard_text_to_file (const gchar * event_group_name, const gchar * event_name
 {
     int file;
     vfs_path_t *fname_vpath = NULL;
-    ssize_t ret;
     size_t str_len;
     const char *text = (const char *) data;
 
@@ -147,7 +143,12 @@ clipboard_text_to_file (const gchar * event_group_name, const gchar * event_name
         return TRUE;
 
     str_len = strlen (text);
-    ret = mc_write (file, (char *) text, str_len);
+    {
+        ssize_t ret;
+
+        ret = mc_write (file, (char *) text, str_len);
+        (void) ret;
+    }
     mc_close (file);
     return TRUE;
 }
