@@ -862,8 +862,7 @@ file_op_context_destroy_ui (file_op_context_t * ctx)
 
         dlg_run_done (ui->op_dlg);
         dlg_destroy (ui->op_dlg);
-        g_free (ui);
-        ctx->ui = NULL;
+        MC_PTR_FREE (ctx->ui);
     }
 }
 
@@ -944,7 +943,7 @@ file_progress_show_count (file_op_context_t * ctx, size_t done, size_t total)
 /* --------------------------------------------------------------------------------------------- */
 
 void
-file_progress_show_total (FileOpTotalContext * tctx, file_op_context_t * ctx,
+file_progress_show_total (file_op_total_context_t * tctx, file_op_context_t * ctx,
                           uintmax_t copied_bytes, gboolean show_summary)
 {
     char buffer[BUF_TINY];
@@ -1087,6 +1086,10 @@ file_progress_show_deleting (file_op_context_t * ctx, const char *s, size_t * co
         return;
 
     ui = ctx->ui;
+
+    if (ui->src_file_label != NULL)
+        label_set_text (ui->src_file_label, _("Deleting"));
+
     label_set_text (ui->src_file, truncFileStringSecure (ui->op_dlg, s));
 
     if (count != NULL)
