@@ -3,8 +3,8 @@
    tree about the changes made to the directory
    structure.
 
-   Copyright (C) 2011, 2013
-   The Free Software Foundation, Inc.
+   Copyright (C) 2011-2014
+   Free Software Foundation, Inc.
 
    Author:
    Janne Kukonlehto
