@@ -252,7 +252,7 @@ static const char *netrcp;
 /* char *ftpfs_translate_path (struct ftpfs_connection *bucket, char *remote_path)
    Translate a Unix path, i.e. MC's internal path representation (e.g.
    /somedir/somefile) to a path valid for the remote server. Every path
-   transfered to the remote server has to be mangled by this function
+   transferred to the remote server has to be mangled by this function
    right prior to sending it.
    Currently only Amiga ftp servers are handled in a special manner.
 
@@ -355,10 +355,7 @@ ftpfs_correct_url_parameters (const vfs_path_element_t * velement)
 
         /* If user is different, remove password */
         if (new_user != NULL && strcmp (path_element->user, new_user) != 0)
-        {
-            g_free (path_element->password);
-            path_element->password = NULL;
-        }
+            MC_PTR_FREE (path_element->password);
 
         g_free (new_user);
         g_free (new_passwd);
@@ -552,8 +549,7 @@ ftpfs_free_archive (struct vfs_class *me, struct vfs_s_super *super)
         close (SUP->sock);
     }
     g_free (SUP->current_dir);
-    g_free (super->data);
-    super->data = NULL;
+    MC_PTR_FREE (super->data);
 }
 
 /* --------------------------------------------------------------------------------------------- */
@@ -887,8 +883,7 @@ ftpfs_open_socket (struct vfs_class *me, struct vfs_s_super *super)
         }
 
         vfs_print_message (_("ftpfs: making connection to %s"), host);
-        g_free (host);
-        host = NULL;
+        MC_PTR_FREE (host);
 
         if (connect (my_socket, curr_res->ai_addr, curr_res->ai_addrlen) >= 0)
             break;
@@ -1657,7 +1652,6 @@ ftpfs_dir_load (struct vfs_class *me, struct vfs_s_inode *dir, char *remote_path
     struct vfs_s_entry *ent;
     struct vfs_s_super *super = dir->super;
     int sock, num_entries = 0;
-    char lc_buffer[BUF_8K];
     int cd_first;
 
     cd_first = ftpfs_first_cd_then_ls || (SUP->strict == RFC_STRICT)
@@ -1705,13 +1699,15 @@ ftpfs_dir_load (struct vfs_class *me, struct vfs_s_inode *dir, char *remote_path
     tty_enable_interrupt_key ();
 
     vfs_parse_ls_lga_init ();
-    while (1)
+    while (TRUE)
     {
         int i;
         size_t count_spaces = 0;
-        int res = vfs_s_get_line_interruptible (me, lc_buffer, sizeof (lc_buffer),
-                                                sock);
-        if (!res)
+        int res;
+        char lc_buffer[BUF_8K] = "\0";
+
+        res = vfs_s_get_line_interruptible (me, lc_buffer, sizeof (lc_buffer), sock);
+        if (res == 0)
             break;
 
         if (res == EINTR)
@@ -2118,10 +2114,7 @@ static void
 ftpfs_fh_free_data (vfs_file_handler_t * fh)
 {
     if (fh != NULL)
-    {
-        g_free (fh->data);
-        fh->data = NULL;
-    }
+        MC_PTR_FREE (fh->data);
 }
 
 /* --------------------------------------------------------------------------------------------- */
@@ -2188,8 +2181,7 @@ ftpfs_fh_open (struct vfs_class *me, vfs_file_handler_t * fh, int flags, mode_t
         if (fh->ino->localname)
         {
             unlink (fh->ino->localname);
-            g_free (fh->ino->localname);
-            fh->ino->localname = NULL;
+            MC_PTR_FREE (fh->ino->localname);
         }
         return 0;
     }
@@ -2420,20 +2412,16 @@ ftpfs_netrc_lookup (const char *host, char **login, char **pass)
     } *rup_cache = NULL, *rupp;
 
     /* Initialize *login and *pass */
-    g_free (*login);
-    *login = NULL;
-    g_free (*pass);
-    *pass = NULL;
+    MC_PTR_FREE (*login);
+    MC_PTR_FREE (*pass);
 
     /* Look up in the cache first */
     for (rupp = rup_cache; rupp != NULL; rupp = rupp->next)
     {
-        if (!strcmp (host, rupp->host))
+        if (strcmp (host, rupp->host) == 0)
         {
-            if (rupp->login)
-                *login = g_strdup (rupp->login);
-            if (pass && rupp->pass)
-                *pass = g_strdup (rupp->pass);
+            *login = g_strdup (rupp->login);
+            *pass = g_strdup (rupp->pass);
             return 0;
         }
     }
