@@ -1,8 +1,8 @@
 /*
    Virtual File System: Midnight Commander file system.
 
-   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2011
-   The Free Software Foundation, Inc.
+   Copyright (C) 1999-2014
+   Free Software Foundation, Inc.
 
    Written by:
    Wayne Roberts <wroberts1@home.com>, 1997
