@@ -2,9 +2,8 @@
    Internal file viewer for the Midnight Commander
    Functions for handle cursor movement
 
-   Copyright (C) 1994, 1995, 1996, 1998, 1999, 2000, 2001, 2002, 2003,
-   2004, 2005, 2006, 2007, 2009, 2011
-   The Free Software Foundation, Inc.
+   Copyright (C) 1994-2014
+   Free Software Foundation, Inc.
 
    Written by:
    Miguel de Icaza, 1994, 1995, 1998
@@ -15,7 +14,7 @@
    Pavel Machek, 1998
    Roland Illig <roland.illig@gmx.de>, 2004, 2005
    Slava Zanko <slavazanko@google.com>, 2009
-   Andrew Borodin <aborodin@vmail.ru>, 2009
+   Andrew Borodin <aborodin@vmail.ru>, 2009, 2013
    Ilia Maslakov <il.smind@gmail.com>, 2009, 2010
 
    This file is part of the Midnight Commander.
@@ -64,17 +63,39 @@
 
 /*** file scope variables ************************************************************************/
 
+/* --------------------------------------------------------------------------------------------- */
 /*** file scope functions ************************************************************************/
 /* --------------------------------------------------------------------------------------------- */
 
+static void
+mcview_scroll_to_cursor (mcview_t * view)
+{
+    if (view->hex_mode)
+    {
+        off_t bytes = view->bytes_per_line;
+        off_t cursor = view->hex_cursor;
+        off_t topleft = view->dpy_start;
+        off_t displaysize;
+
+        displaysize = view->data_area.height * bytes;
+        if (topleft + displaysize <= cursor)
+            topleft = mcview_offset_rounddown (cursor, bytes) - (displaysize - bytes);
+        if (cursor < topleft)
+            topleft = mcview_offset_rounddown (cursor, bytes);
+        view->dpy_start = topleft;
+    }
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
 static void
 mcview_movement_fixups (mcview_t * view, gboolean reset_search)
 {
     mcview_scroll_to_cursor (view);
     if (reset_search)
     {
-        view->search_start = view->dpy_start;
-        view->search_end = view->dpy_start;
+        view->search_start = view->hex_mode ? view->hex_cursor : view->dpy_start;
+        view->search_end = view->search_start;
     }
     view->dirty++;
 }
@@ -277,26 +298,6 @@ mcview_move_right (mcview_t * view, off_t columns)
 
 /* --------------------------------------------------------------------------------------------- */
 
-void
-mcview_scroll_to_cursor (mcview_t * view)
-{
-    if (view->hex_mode)
-    {
-        const off_t bytes = view->bytes_per_line;
-        const off_t displaysize = view->data_area.height * bytes;
-        const off_t cursor = view->hex_cursor;
-        off_t topleft = view->dpy_start;
-
-        if (topleft + displaysize <= cursor)
-            topleft = mcview_offset_rounddown (cursor, bytes) - (displaysize - bytes);
-        if (cursor < topleft)
-            topleft = mcview_offset_rounddown (cursor, bytes);
-        view->dpy_start = topleft;
-    }
-}
-
-/* --------------------------------------------------------------------------------------------- */
-
 void
 mcview_moveto_top (mcview_t * view)
 {
@@ -480,7 +481,7 @@ mcview_place_cursor (mcview_t * view)
     screen_dimen col = view->cursor_col;
     if (!view->hexview_in_text && view->hexedit_lownibble)
         col++;
-    widget_move (&view->widget, top + view->cursor_row, left + col);
+    widget_move (view, top + view->cursor_row, left + col);
 }
 
 /* --------------------------------------------------------------------------------------------- */
@@ -491,19 +492,15 @@ mcview_place_cursor (mcview_t * view)
 void
 mcview_moveto_match (mcview_t * view)
 {
-    off_t offset;
-
-    offset = view->search_start;
-
     if (view->hex_mode)
     {
-        view->hex_cursor = offset;
-        view->dpy_start = offset - offset % view->bytes_per_line;
+        view->hex_cursor = view->search_start;
+        view->hexedit_lownibble = FALSE;
+        view->dpy_start = view->search_start - view->search_start % view->bytes_per_line;
+        view->dpy_end = view->search_end - view->search_end % view->bytes_per_line;
     }
     else
-    {
-        view->dpy_start = mcview_bol (view, offset, 0);
-    }
+        view->dpy_start = mcview_bol (view, view->search_start, 0);
 
     mcview_scroll_to_cursor (view);
     view->dirty++;
