@@ -1,11 +1,11 @@
 /*
    lib/vfs - test vfs_s_get_path() function
 
-   Copyright (C) 2011
-   The Free Software Foundation, Inc.
+   Copyright (C) 2011-2014
+   Free Software Foundation, Inc.
 
    Written by:
-   Slava Zanko <slavazanko@gmail.com>, 2011
+   Slava Zanko <slavazanko@gmail.com>, 2011, 2013
 
    This file is part of the Midnight Commander.
 
@@ -21,17 +21,14 @@
 
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+ */
 
 #define TEST_SUITE_NAME "/lib/vfs"
 
-#include <config.h>
+#include "tests/mctest.h"
 
-#include <check.h>
-
-#include "lib/global.h"
 #include "lib/strutil.h"
-#include "lib/vfs/direntry.c" /* for testing static methods  */
+#include "lib/vfs/direntry.c"   /* for testing static methods  */
 
 #include "src/vfs/local/local.c"
 
@@ -43,26 +40,28 @@
 struct vfs_s_subclass test_subclass1, test_subclass2, test_subclass3;
 struct vfs_class vfs_test_ops1, vfs_test_ops2, vfs_test_ops3;
 
+/* --------------------------------------------------------------------------------------------- */
+
 static int
-test1_mock_open_archive(struct vfs_s_super *super, const vfs_path_t *vpath, const vfs_path_element_t *vpath_element)
+test1_mock_open_archive (struct vfs_s_super *super, const vfs_path_t * vpath,
+                         const vfs_path_element_t * vpath_element)
 {
     struct vfs_s_inode *root;
-    char *spath = vfs_path_to_str (vpath);
 
-    fail_unless(strcmp("/" ETALON_VFS_URL_NAME ARCH_NAME, spath) == 0,
-        "etalon(%s) doesn't equal to actual(%s)", "/" ETALON_VFS_URL_NAME ARCH_NAME, spath);
+    mctest_assert_str_eq (vfs_path_as_str (vpath), "/" ETALON_VFS_URL_NAME ARCH_NAME);
 
-    super->name = g_strdup (spath);
+    super->name = g_strdup (vfs_path_as_str (vpath));
     super->data = g_new (char *, 1);
     root = vfs_s_new_inode (vpath_element->class, super, NULL);
     super->root = root;
-    g_free(spath);
     return 0;
 }
 
+/* --------------------------------------------------------------------------------------------- */
+
 static int
-test1_mock_archive_same (const vfs_path_element_t *vpath_element, struct vfs_s_super *super,
-                        const vfs_path_t *vpath, void *cookie)
+test1_mock_archive_same (const vfs_path_element_t * vpath_element, struct vfs_s_super *super,
+                         const vfs_path_t * vpath, void *cookie)
 {
     const vfs_path_element_t *path_element;
 
@@ -70,12 +69,15 @@ test1_mock_archive_same (const vfs_path_element_t *vpath_element, struct vfs_s_s
     (void) super;
     (void) cookie;
 
-    path_element = vfs_path_get_by_index(vpath, -1);
-    if (strcmp(ARCH_NAME, path_element->path) != 0)
+    path_element = vfs_path_get_by_index (vpath, -1);
+    if (strcmp (ARCH_NAME, path_element->path) != 0)
         return 0;
     return 1;
 }
 
+/* --------------------------------------------------------------------------------------------- */
+
+/* @Before */
 static void
 setup (void)
 {
@@ -109,6 +111,9 @@ setup (void)
     vfs_register_class (&vfs_test_ops3);
 }
 
+/* --------------------------------------------------------------------------------------------- */
+
+/* @After */
 static void
 teardown (void)
 {
@@ -120,31 +125,37 @@ teardown (void)
 void
 vfs_die (const char *m)
 {
-    printf("VFS_DIE: '%s'\n", m);
+    printf ("VFS_DIE: '%s'\n", m);
 }
 
 /* --------------------------------------------------------------------------------------------- */
 
+/* @Test */
+/* *INDENT-OFF* */
 START_TEST (test_vfs_s_get_path)
+/* *INDENT-ON* */
 {
+    /* given */
     struct vfs_s_super *archive;
-
     const char *result;
-    vfs_path_t *vpath = vfs_path_from_str_flags ("/" ETALON_VFS_NAME ARCH_NAME "#test1:/" ETALON_PATH,
-            VPF_USE_DEPRECATED_PARSER);
+
+    /* when */
+    vfs_path_t *vpath =
+        vfs_path_from_str_flags ("/" ETALON_VFS_NAME ARCH_NAME "#test1:/" ETALON_PATH,
+                                 VPF_USE_DEPRECATED_PARSER);
 
     result = vfs_s_get_path (vpath, &archive, 0);
 
-    fail_unless(strcmp(ETALON_PATH, result) == 0,
-        "expected(%s) doesn't equal to actual(%s)", ETALON_PATH, result);
+    /* then */
+    mctest_assert_str_eq (result, ETALON_PATH);
+    mctest_assert_str_eq (archive->name, "/" ETALON_VFS_URL_NAME ARCH_NAME);
 
-    fail_unless(strcmp("/" ETALON_VFS_URL_NAME ARCH_NAME,archive->name) == 0,
-        "expected(%s) doesn't equal to actual(%s)", "/" ETALON_VFS_URL_NAME ARCH_NAME, archive->name);
-
-    g_free(vpath);
+    g_free (vpath);
 
 }
+/* *INDENT-OFF* */
 END_TEST
+/* *INDENT-ON* */
 
 /* --------------------------------------------------------------------------------------------- */
 
